@@ -1,5 +1,7 @@
-from typing import Tuple
-from hathi.scanner import ScanResult, Scanner
+import os
+from typing import Optional, Tuple
+
+from hathi.scanner import Scanner, ScanResult
 
 try:
     import pymssql
@@ -8,7 +10,6 @@ try:
 except ImportError:
     MSSQL_SUPPORT = False
 
-
 MSSQL_USERNAME_LIST = """
 admin
 administrator
@@ -24,7 +25,12 @@ wordpress
 
 
 def _mssql_try_host(
-    scanner: Scanner, host, username, password, database
+    scanner: Scanner,
+    host: str,
+    username: str,
+    password: str,
+    database: str,
+    no_ssl: Optional[bool],
 ) -> Tuple[ScanResult, str, str, str]:
     try:
         conn = pymssql.connect(
@@ -35,8 +41,14 @@ def _mssql_try_host(
         )
         conn.close()
         return ScanResult.Success, host, username, password
-    except pymssql.OperationalError:
-        return ScanResult.BadPassword, host, username, password
+    except pymssql.OperationalError as oe:
+        code, *_ = oe.args[0]
+        if os.getenv("HATHI_DEBUG", False):
+            print(oe.args)
+        if code == 18456:
+            return ScanResult.BadPassword, host, username, password
+        else:
+            return ScanResult.Error, host, username, password
 
 
 class MssqlScanner(Scanner):
